@@ -94,7 +94,7 @@ def main() -> None:
 
     :return none:
     """
-    asyncio.set_event_loop(asyncio.ProactorEventLoop())
+    asyncio.set_event_loop(asyncio.SelectorEventLoop())
     clear()
     print(ASCII)
     console.info("Welcome to OneSnipe - Created by Geographs#0404\n")
